@@ -2,6 +2,7 @@
 
 import os
 import sys
+import ast
 import traceback
 from argparse import ArgumentParser
 import onnx
@@ -292,7 +293,7 @@ def order_conversion(
     transpose_nodes = []
     next_nodes = []
     if input_op_names_and_order_dims:
-        for graph_input in graph.inputs:
+        for transpose_idx, graph_input in enumerate(graph.inputs):
             if graph_input.name in new_input_shapes:
 
                 # Rewriting of graph input OP variable
@@ -307,6 +308,7 @@ def order_conversion(
                 )
                 transpose = gs.Node(
                     op="Transpose",
+                    name=f"input_order_convert_transpose_{transpose_idx}",
                     attrs={"perm": inverted_list[graph_input.name]},
                     inputs=[graph_input],
                     outputs=[transpose_out]
@@ -506,7 +508,7 @@ def main():
     input_op_names_and_order_dims_tmp = None
     if input_op_names_and_order_dims:
         input_op_names_and_order_dims_tmp = {
-            input_op_names_and_order_dim[0]: eval(input_op_names_and_order_dim[1]) for input_op_names_and_order_dim in input_op_names_and_order_dims
+            input_op_names_and_order_dim[0]: ast.literal_eval(input_op_names_and_order_dim[1]) for input_op_names_and_order_dim in input_op_names_and_order_dims
         }
 
     # channel_change_inputs
